@@ -1,9 +1,16 @@
 // rte_window.h
 // LiVES (lives-exe)
-// (c) G. Finch 2005 - 2010
+// (c) G. Finch 2005 - 2013
 // released under the GNU GPL 3 or later
 // see file ../COPYING or www.gnu.org for licensing details
 
+#ifndef HAS_LIVES_RTE_WINDOW_H
+#define HAS_LIVES_RTE_WINDOW_H
+
+#define RTE_INFO_WIDTH ((int)(350.*widget_opts.scale))
+#define RTE_INFO_HEIGHT ((int)(200.*widget_opts.scale))
+
+
 void on_assign_rte_keys_activate (GtkMenuItem *, gpointer);
 void on_rte_info_clicked (GtkButton *, gpointer data);
 void load_default_keymap(void);
@@ -25,3 +32,5 @@ void rte_reset_defs_clicked (GtkButton *, lives_rfx_t *rfx);
 void rte_set_key_defs (GtkButton *, lives_rfx_t *);
 void on_save_rte_defs_activate (GtkMenuItem *, gpointer);
 boolean on_clear_all_clicked (GtkButton *, gpointer user_data);
+
+#endif // HAS_LIVES_RTE_WINDOW_H
